# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# noarch, but to avoid *.list files interfering with signature test
%global debug_package %{nil}

# Store keys in a temp directory
%global gnupghome %(mktemp --directory)

Name:		perl-constant-boolean
Version:	0.02
Release:	37.%{__distinit}%{__distvers}
Summary:	Define TRUE and FALSE constants
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/constant-boolean
Source0:	https://cpan.metacpan.org/authors/id/D/DE/DEXTER/constant-boolean-%{version}.tar.gz
Source1:	C0B10A5B.pub
Patch0:		constant-boolean-0.02-Critic.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gnupg
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(strict)
BuildRequires:	perl(Symbol::Util)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(Test::More) >= 0.88
# Release Tests
BuildRequires:	patchutils
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Slurp)
BuildRequires:	perl(Test::CheckChanges)
BuildRequires:	perl(Test::Distribution)
BuildRequires:	perl(Test::Kwalitee)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.14
BuildRequires:	perl(Test::Pod::Coverage) >= 1.04
BuildRequires:	perl(Test::Signature)
BuildRequires:	perl(Test::Spelling), hunspell-en
BuildRequires:	sed
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Symbol::Util)

%description
Defines TRUE and FALSE constants in caller's namespace. You could use
simple values like empty string or zero for false, or any non-empty and non-
zero string value as true, but the TRUE and FALSE constants are more
descriptive.

%prep
%setup -q -n constant-boolean-%{version}

# Import upstream's GPG key so we don't need to fetch it from a keyserver
# when running the signature test
export GNUPGHOME=%{gnupghome}
gpg2 --import %{SOURCE1}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
# === MAIN TEST SUITE === #
make test

# ===  RELEASE TESTS  === #
export GNUPGHOME=%{gnupghome}
RELEASE_TESTS="$(echo xt/*.t | sed 's|xt/copyright.t||')"
# Don't run the copyright test as it will fail after the year of module release
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/copyright.t||')"
# Don't run the perlcritic test yet as we need to patch the code
RELEASE_TESTS="$(echo $RELEASE_TESTS | sed 's|xt/perlcritic.t||')"
# Signature test would fail on recent distros due to presence of MYMETA.json/MYMETA.yml
[ -f MYMETA.json ] && mv MYMETA.json ..
[ -f MYMETA.yml ] && mv MYMETA.yml ..
make test TEST_FILES="$RELEASE_TESTS"
[ -f ../MYMETA.json ] && mv ../MYMETA.json .
[ -f ../MYMETA.yml ] && mv ../MYMETA.yml .
# Patch the code to turn off one check before running the perlcritic test
patch -p0 < %{P:0}
make test TEST_FILES=xt/perlcritic.t
patch -p0 -R < %{P:0}

%clean
rm -rf %{buildroot} %{gnupghome}

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/constant/
%{_mandir}/man3/constant::boolean.3*

%changelog
* Fri Jun  2 2023 Paul Howarth <paul@city-fan.org> - 0.02-37
- Use SPDX-format license tag
- Use %%license unconditionally

* Sun Jun  9 2019 Paul Howarth <paul@city-fan.org> - 0.02-25
- Modernize spec
  - Switch upstream from search.cpan.org to metacpan.org
  - Use mktemp to create GNUPGHOME, simplifying build process
  - BR: perl-generators unconditionally
  - BR: perl-interpreter rather than perl
  - Don't explicitly clean buildroot in %%install section
  - Drop support for building with Test::More < 0.88
  - Drop legacy BuildRoot: and Group: tags
  - Spell check backend is always hunspell

* Wed Aug 10 2016 Paul Howarth <paul@city-fan.org> - 0.02-17
- Fix FTBFS when perl is not in the minimal buildroot
- Classify buildreqs by usage
- Simplify find command using -delete

* Wed Sep 17 2014 Paul Howarth <paul@city-fan.org> - 0.02-13
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Jul 25 2013 Paul Howarth <paul@city-fan.org> - 0.02-10
- Perl 5.18 rebuild

* Mon Jul  1 2013 Paul Howarth <paul@city-fan.org> - 0.02-8
- Tweak the perlcritic test, which has discovered something to moan about

* Sun Jul 15 2012 Paul Howarth <paul@city-fan.org> - 0.02-7
- Add runtime dependency on perl(Symbol::Util)
- BR: perl(Carp), perl(Cwd), perl(File::Spec) and perl(Test::Harness)
- Work around release test failure due to presence of MYMETA.json
- Specify version requirements for Test::Pod and Test::Pod::Coverage
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Test::Perl::Critic is always available
  - aspell-en-gb is never needed
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul 27 2011 Paul Howarth <paul@city-fan.org> - 0.02-5
- Rebuild for perl 5.14.1 in Rawhide
- Work around auto-generated MYMETA file breaking signature test
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.02-4
- Import from Fedora

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.02-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 15 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.02-2
- Rebuild to fix problems with vendorarch/lib (#661697)

* Fri May 07 2010 Emmanuel Seyman <emmanuel.seyman@club-internet.fr> - 0.02-1
- Update to 0.02

* Fri Apr 30 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.01-6
- Mass rebuild with perl-5.12.0

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.01-5
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.01-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.01-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sun Feb 01 2009 Allisson Azevedo <allisson@gmail.com> - 0.01-2
- Rebuild

* Thu Jan 29 2009 Allisson Azevedo <allisson@gmail.com> 0.01-1
- Initial rpm release
